==> guarana-1.3.tar.gz: guarana-1.3/sample/tutorial-src/ModifyResult.java <==
// $Id: ModifyResult.java,v 1.1 1998/06/05 12:22:45 oliva Exp $

/* Copyright 1998 Alexandre Oliva <oliva@dcc.unicamp.br>
 *
 * This file is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

import BR.unicamp.Guarana.*;

/**
 * This example shows how to modify results of Operations.  The
 * MetaObject implemented by this class causes method hashCode of
 * objects it intercepts to always return 0, and causes method
 * toString to have a `modified' word prepended to the original
 * result.
 *
 * @author Alexandre Oliva
 * @version $Revision: 1.1 $
 */
public class ModifyResult extends MetaObject {
    final static java.lang.reflect.Method hashCode, toString;
    static {
	try { hashCode = Object.class.getDeclaredMethod("hashCode", new Class[0]); }
	catch (NoSuchMethodException e) { hashCode = null; }
	try { toString = Object.class.getDeclaredMethod("toString", new Class[0]); }
	catch (NoSuchMethodException e) { toString = null; }
    } 
    public Result handle(final Operation op, final Object ob) {
	final java.lang.reflect.Method meth = op.getMethod();
	if (hashCode.equals(meth))
	    return Result.returnInt(0, op);
	if (toString.equals(meth))
	    return Result.modifyResult;
	return Result.noResult;
    }
    public Result handle(final Result res, final Object ob) {
	Operation op = res.getOperation();
	if (toString.equals(op.getMethod()))
	    return Result.returnObject("modified " + res.getObjectValue(), op);
	return null;
    }
    public static void main(String[ ] argv) {
	Object o = new Object();
	MetaObject[ ] mos = new MetaObject[ ] {
	    new MetaLogger().setPrefix("a: "),
	    new ModifyResult(),
	    new MetaLogger().setPrefix("b: ") };
	Guarana.reconfigure(o, null, new SequentialComposer(mos));
	System.out.println(o);
    }
}

==> guarana-1.4.tar.gz: guarana-1.4/sample/tutorial-src/ModifyResult.java <==
// $Id: ModifyResult.java,v 1.3 1998/07/28 10:12:27 oliva Exp $

/* Copyright 1998 Alexandre Oliva <oliva@dcc.unicamp.br>
 *
 * This file is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

import BR.unicamp.Guarana.*;

/**
 * This example shows how to modify results of Operations.  The
 * MetaObject implemented by this class causes method hashCode of
 * objects it intercepts to always return 0, and causes method
 * toString to have a `modified' word prepended to the original
 * result.
 *
 * @author Alexandre Oliva
 * @version $Revision: 1.3 $
 */
public class ModifyResult extends MetaObject {
    final static java.lang.reflect.Method hashCode, toString;
    static {
	try { hashCode =
		  Object.class.getDeclaredMethod("hashCode", new Class[0]);
	} catch (NoSuchMethodException e) { hashCode = null; }
	try { toString =
		  Object.class.getDeclaredMethod("toString", new Class[0]);
	} catch (NoSuchMethodException e) { toString = null; }
    } 
    public Result handle(final Operation op, final Object ob) {
	final java.lang.reflect.Method meth = op.getMethod();
	if (hashCode.equals(meth))
	    return Result.returnInt(0, op);
	if (toString.equals(meth))
	    return Result.modifyResult;
	return Result.noResult;
    }
    public Result handle(final Result res, final Object ob) {
	Operation op = res.getOperation();
	if (toString.equals(op.getMethod()))
	    return Result.returnObject("modified "
				       + res.getObjectValue(), op);
	return null;
    }
    public static void main(String[ ] argv) {
	Object o = new Object();
	MetaObject[ ] mos = {
	    new MetaLogger().setPrefix("a: "),
	    new ModifyResult(),
	    new MetaLogger().setPrefix("b: ") };
	Guarana.reconfigure(o, null, new SequentialComposer(mos));
	System.out.println(o);
    }
}
